@@ -11,14 +11,18 @@ from . import tables
 from . import cost_index
 from . import batch
 from . import specification_factors
+from . import column_design
 
 __all__ = (*cost_index.__all__,
            *vacuum.__all__,
            *tables.__all__,
            *batch.__all__,
            *specification_factors.__all__,
+           *column_design.__all__,
 )
+
 from .specification_factors import *
+from .column_design import *
 from .vacuum import *
 from .tables import *
 from .cost_index import *
